pub async fn collect_admin_snapshot(photon: &Photon) -> Result<AdminSnapshot>Expand description
Build a full admin snapshot for the given runtime (async checkpoint reads).
Errors
Returns an error if a checkpoint load fails.
pub async fn collect_admin_snapshot(photon: &Photon) -> Result<AdminSnapshot>Build a full admin snapshot for the given runtime (async checkpoint reads).
Returns an error if a checkpoint load fails.